@@ -36,7 +36,7 @@ fn lex_(mut input: &str, mut start_of_line: bool) -> impl Iterator<Item = (Synta
     std::iter::from_fn(move || {
         if let Some(c) = input.chars().next() {
             match c {
-                ':' if colon_count == 0 => {
+                ':' if colon_count == 0 && indent == 0 => {
                     colon_count += 1;
                     let char_len = c.len_utf8();
                     input = &input[char_len..];
@@ -285,4 +285,31 @@ Section: vcs
             ]
         );
     }
+
+    #[test]
+    fn test_lex_continuation_starting_with_colon() {
+        // Test continuation line that STARTS with a colon
+        // This was the bug reported in issue #315
+        let text = "Package: test\nDescription: short\n :value\n";
+        let tokens = super::lex(text).collect::<Vec<_>>();
+
+        assert_eq!(
+            tokens,
+            vec![
+                (KEY, "Package"),
+                (COLON, ":"),
+                (WHITESPACE, " "),
+                (VALUE, "test"),
+                (NEWLINE, "\n"),
+                (KEY, "Description"),
+                (COLON, ":"),
+                (WHITESPACE, " "),
+                (VALUE, "short"),
+                (NEWLINE, "\n"),
+                (INDENT, " "),
+                (VALUE, ":value"),
+                (NEWLINE, "\n")
+            ]
+        );
+    }
 }
